MorpheusPrivate class

Implemented types

Properties

devices MorpheusPrivateKind
no setter
groups MorpheusPrivateKind
no setter
hashCode int
The hash code for this object.
no setterinherited
personas MorpheusPrivateKind
no setter
public MorpheusPublic
no setter
resources MorpheusPrivateKind
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
override
keyByPk(PublicKey pk) MorpheusPrivateKey
kind(String didKind) MorpheusPrivateKind
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signClaimPresentation(KeyId id, Presentation presentation) Signed<Presentation>
signDidOperations(KeyId id, ByteData data) Signed<ByteData>
signWitnessRequest(KeyId id, WitnessRequest request) Signed<WitnessRequest>
signWitnessStatement(KeyId id, WitnessStatement statement) Signed<WitnessStatement>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited