MorpheusApi class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
beforeProofExists(ContentId contentId, {int? height})
→ Future<bool>
-
-
checkTransactionValidity(MorpheusAsset asset)
→ Future<List<DryRunOperationError<OperationData>>>
-
-
getBeforeProofHistory(ContentId contentId)
→ Future<BeforeProofHistoryResponse>
-
-
getDidDocument(Did did, {int? height})
→ Future<DidDocument>
-
-
getDidOperationAttempts(Did did, int fromHeight, {int? untilHeight})
→ Future<List<DidOperation>?>
-
-
getDidOperations(Did did, int fromHeight, {int? untilHeight})
→ Future<List<DidOperation>?>
-
-
getDidTransactionAttemptIds(Did did, int fromHeight, {int? untilHeight})
→ Future<List<TransactionIdHeight>?>
-
-
getDidTransactionIds(Did did, int fromHeight, {int? untilHeight})
→ Future<List<TransactionIdHeight>?>
-
-
getLastTxId(Did did)
→ Future<String?>
-
-
getTxnStatus(String txId)
→ Future<bool?>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited